@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply arpeggiation patterns to groups of notes
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
@@ -118,7 +118,7 @@ Music::MelodicDevice::Arpeggiation - Apply arpeggiation patterns to groups of no
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -183,9 +183,10 @@ Show progress.
 =head2 new
 
   $x = Music::MelodicDevice::Arpeggiation->new(
-    scale_note => $scale_note,
-    scale_name => $scale_name,
-    verbose    => $verbose,
+    type     => $type,
+    duration => $duration,
+    repeats  => $repeats,
+    verbose  => $verbose,
   );
 
 Create a new C<Music::MelodicDevice::Arpeggiation> object.
